pub struct MultimapTableDefinition<'a, K, V>{ /* private fields */ }Expand description
Defines the name and types of a multimap table
A MultimapTableDefinition should be opened for use by calling ReadTransaction::open_multimap_table or WriteTransaction::open_multimap_table
Multimap tables may have multiple values associated with each key
Note that the lifetime of the K and V type parameters does not impact the lifetimes of the data
that is stored or retreived from the table
Implementations
Sourceimpl<'a, K, V> MultimapTableDefinition<'a, K, V>
impl<'a, K, V> MultimapTableDefinition<'a, K, V>
Sourcepub const fn new(name: &'a str) -> MultimapTableDefinition<'a, K, V>
pub const fn new(name: &'a str) -> MultimapTableDefinition<'a, K, V>
Construct a new multimap table with given name
Panics
Panics if name is empty. When name is a non-empty string literal
this is checked at compile time, but callers that build the name at
runtime are responsible for ensuring it is non-empty.