pub struct TableDefinition<'a, K, V>{ /* private fields */ }Expand description
Defines the name and types of a table
A TableDefinition should be opened for use by calling ReadTransaction::open_table or WriteTransaction::open_table
Note that the lifetime of the K and V type parameters does not impact the lifetimes of the data
that is stored or retreived from the table
Implementations
Sourceimpl<'a, K, V> TableDefinition<'a, K, V>
impl<'a, K, V> TableDefinition<'a, K, V>
Sourcepub const fn new(name: &'a str) -> TableDefinition<'a, K, V>
pub const fn new(name: &'a str) -> TableDefinition<'a, K, V>
Construct a new table with given name
Panics
Panics if name is empty. When name is a non-empty string literal
this is checked at compile time, but callers that build the name at
runtime are responsible for ensuring it is non-empty.